vdr + xine 0.7.4 - now using the budget card.

Message ID 87r7g8dtp9.87psvsdtp9@87oebcdtp9.message.id
State New
Headers

Commit Message

syrius.ml@no-log.org May 15, 2005, 11:40 p.m. UTC
  Reinhard Nissl <rnissl@gmx.de> writes:

[...]
>> And I've discovered vdr is now using my budget card (card #2) for
>> live tv while it was using the ff one (card #1) before.
>> PrimaryDVB = 3
>> xine.autoPrimaryDeviceMode = autoPrimaryDeviceOff
>> I don't use the FF output at all, but I'd prefer to have the FF card
>> used for live TV. Is there something I missed ? is there a setting
>> for that ? (iirc, a change concerning the fact vdr prefers budget
>> cards to record has been made in vdr but i'm not sure it's really
>> related)
>
> I think, finding a device as source for transfer mode respectively
> recording is handled identically. So the change in 1.3.24 hits you ;-)

in fact you're right.
I've modified the check so that it set pri to 2 if Priority is also
greater than 0.
I assume most plugins call cDevice::GetDevice with Priority=0 and
records default to 50.
Records with Priority==0 won't be recorded by budget cards by default.

I'm pretty sure a cleaner solution exists.



--
  

Patch

--- /tmp/device.c       2005-05-16 01:25:48.000000000 +0200
+++ device.c    2005-05-16 01:38:36.000000000 +0200
@@ -283,4 +283,4 @@ 
             pri = 1; // free and fewer Ca's
-         else if (!device[i]->Receiving() && !device[i]->HasDecoder())
-            pri = 2; // free and not a full featured card 
+         else if (!device[i]->Receiving() && !device[i]->HasDecoder() && Priority > 0)
+            pri = 2; // free and not a full featured card and Priority > 0
          else if (!device[i]->Receiving() && !device[i]->IsPrimaryDevice())